@@ -1,11 +1,16 @@
 from __future__ import annotations
 
-__all__ = ("Unzip",)
+__all__ = (
+    "Unzip",
+    "is_image_sequence",
+    "is_dot_file",
+)
 
 import functools
 import io
 import re
 import zipfile
+import pathlib
 from collections.abc import Iterable, Callable
 from types import TracebackType
 from typing import Optional, Type, Union, BinaryIO
@@ -59,6 +64,23 @@ class Unzip:
         path: Optional[PathLike] = None,
         files: Optional[Iterable[PathLike]] = None,
         pwd: Optional[bytes] = None,
+    ) -> list[str]:
+        """
+        :deprecated: 1.3.0
+        """
+        from warnings import warn
+
+        warn(
+            "__call__ method is officially deprecated and will be removed in lambda-utility v1.3.0"
+        )
+        return self.extract_all(path=path, files=files, pwd=pwd)
+
+    def extract_all(
+        self,
+        *,
+        path: Optional[PathLike] = None,
+        files: Optional[Iterable[PathLike]] = None,
+        pwd: Optional[bytes] = None,
     ) -> list[str]:
         if path is not None:
             path = str(path)
@@ -70,6 +92,18 @@ class Unzip:
         self.zip_ref.extractall(path=path, members=members, pwd=pwd)
         return members
 
+    def extract_all_in_memory(
+        self,
+        files: Optional[Iterable[PathLike]] = None,
+        pwd: Optional[bytes] = None,
+    ) -> Iterable[tuple[str, bytes]]:
+        if files is None:
+            files = self.get_valid_namelist()
+
+        for filename in files:
+            filename = str(filename)
+            yield filename, self.zip_ref.read(str(filename), pwd=pwd)
+
     @functools.lru_cache
     def get_valid_namelist(self) -> tuple[str, ...]:
         return tuple(
@@ -127,3 +161,54 @@ class Unzip:
 
         sorted_result = sorted(sequence_names.items())
         return tuple(name for _, name in sorted_result)
+
+
+def is_image_sequence(
+    path: PathLike, *, allowed_extension: Optional[str] = None
+) -> bool:
+    """validate image seuqnece file
+    {sequence number}.{extension} or {filename}_{sequence number}.{extension}
+    :examples:
+        >>> is_image_sequence("path/to/cat_001.png")
+        True
+        >>> is_image_sequence(PathExt("path/to/001.png"))
+        True
+        >>> is_image_sequence("path/to/cat001.png")
+        False
+        >>> is_image_sequence("path/to/cat_001.webp")
+        False
+        >>> is_image_sequence("path/to/cat_001.webp", allowed_extension="webp")
+        True
+    """
+    if not isinstance(path, pathlib.Path):
+        path = pathlib.Path(path)
+
+    if allowed_extension is None:
+        return bool(
+            re.fullmatch(
+                r"^(.*_)?(\d+)\.([pP][nN][gG]|[jJ][pP][gG]|[jJ][pP][eE][gG])$",
+                path.name,
+            )
+        )
+    else:
+        return bool(re.fullmatch(fr"^(.*_)?(\d+)\.({allowed_extension})$", path.name))
+
+
+def is_dot_file(path: PathLike) -> bool:
+    """validate a dot file (like a system file)
+    :examples:
+        >>> is_dot_file("path/to/.hello.png")
+        True
+        >>> is_dot_file("path/to/hello.png")
+        False
+    """
+    if not isinstance(path, pathlib.Path):
+        path = pathlib.Path(path)
+
+    return path.name.startswith(".")
+
+
+if __name__ == "__main__":
+    import doctest
+
+    doctest.testmod()
